@@ -40,12 +40,21 @@ using namespace KHC;
 class HelpUrlSchemeHandler : public QWebEngineUrlSchemeHandler {
     void requestStarted(QWebEngineUrlRequestJob* job) override {
         qCDebug(KHC_LOG) << job->requestUrl();
-        KIO::TransferJob* kiojob = KIO::get(job->requestUrl(), KIO::NoReload);
+        KIO::TransferJob* kiojob = KIO::get(job->requestUrl(), KIO::NoReload, KIO::HideProgressInfo);
+        // QWebEngineUrlRequestJob seems to not support redirect & content at the same time
+        kiojob->setRedirectionHandlingEnabled(false);
         QByteArray result;
         connect(kiojob, &KIO::TransferJob::data, this, [&result](KJob*, QByteArray data) {
             result += data;
         });
         kiojob->exec();
+
+        const QUrl redirectUrl = kiojob->redirectUrl();
+        if (redirectUrl.isValid()) {
+            job->redirect(redirectUrl);
+            return;
+        }
+
         auto buffer = new QBuffer(job);
         buffer->setData(result);
         job->reply("text/html", buffer);
@@ -76,6 +85,20 @@ View::View( QWidget *parentWidget, KActionCollection *col )
         customScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
         QWebEngineUrlScheme::registerScheme(customScheme);
     }
+    {
+        QWebEngineUrlScheme customScheme("info");
+        customScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored | QWebEngineUrlScheme::LocalScheme
+                              | QWebEngineUrlScheme::LocalAccessAllowed);
+        customScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
+        QWebEngineUrlScheme::registerScheme(customScheme);
+    }
+    {
+        QWebEngineUrlScheme customScheme("glossentry");
+        customScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored | QWebEngineUrlScheme::LocalScheme
+                              | QWebEngineUrlScheme::LocalAccessAllowed);
+        customScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
+        QWebEngineUrlScheme::registerScheme(customScheme);
+    }
 
     page()->settings()->setUnknownUrlSchemePolicy(QWebEngineSettings::AllowAllUnknownUrlSchemes);
     page()->settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled,true);
@@ -87,7 +110,8 @@ View::View( QWidget *parentWidget, KActionCollection *col )
     page()->profile()->installUrlSchemeHandler(QByteArrayLiteral("help"),new HelpUrlSchemeHandler);
     page()->profile()->installUrlSchemeHandler(QByteArrayLiteral("khelpcenter"),new HelpUrlSchemeHandler);
     page()->profile()->installUrlSchemeHandler(QByteArrayLiteral("man"),new HelpUrlSchemeHandler);
-    QString css = langLookup(QStringLiteral("kdoctools5-common/kde-default.css"));
+    page()->profile()->installUrlSchemeHandler(QByteArrayLiteral("info"),new HelpUrlSchemeHandler);
+    QString css = langLookup(QStringLiteral("kdoctools6-common/kde-default.css"));
     if (!css.isEmpty())
     {
 
